/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

1.) 
Estimates survivor functions for the transition to grandparenthood for each country for all, men and women.
Estimates are stored in ${logdir}/SF_GPH_{group=all|men|women}_{country id}

2.) Plots Figure A1 
FIGURE A1 Survivor functions for the transition to grandparenthood (part I)
FIGURE A1 Survivor functions for the transition to grandparenthood (part II)

*/

clear 

use ${prepared}/transitions, clear

* Estimate survivor functions

stset t [iweight=nweight] , f(d)  
capt drop woman
gen woman = man==0
glo sccomb "" 
* glo hzcomb ""

foreach num of numlist 1/31 {
	
	count if country==`num'
	if `r(N)'==0 continue
	local c: label (country) `num'
	
	
	* >>> text labels 
	capt ma drop ESS GSS datasource
	capt ma drop Nunits Nevents
	sum maxESS if country==`num'
	local ESS "`r(max)'"
	sum maxGGS if country==`num'
	local GSS  "`r(max)'"
	if "`ESS'" == "1" {
		local datasource "Data: ESS"
	}
	else if "`GSS'" == "1" { 
		local datasource "Data: GGS"
	}
	else {
		local datasource "Data: NSFH"
	}
	quiet: stdes if country==`num'
	local Nunits  = `r(N_total)'
	local Nevents  = `r(N_fail)'
	* <<< text labels 
	
	quiet: stsum if country==`num'
	local p75 "`r(p75)'"
	if "`p75'"=="." local p75 ""
	local p50 "`r(p50)'"
	local p25 "`r(p25)'"
	
	
	tempfile all m f
	preserve
		// sts list, saving(${logdir}/SF_GPH_all_`num', replace)
		log using ${logdir}/SF_GPH_all_`num', smcl replace
		sts list if country==`num', saving(${logdir}/SF_GPH_all_`num', replace)
		log close
		use ${logdir}/SF_GPH_all_`num', clear
		keep time survivor
		rename survivor S_all
		save `all', replace
	restore
	preserve
		// sts list, saving(${logdir}/SF_GPH_women_`num', replace)
		log using ${logdir}/SF_GPH_women_`num', smcl replace
		sts list if man==0 & country==`num', saving(${logdir}/SF_GPH_women_`num', replace)
		log close
		use ${logdir}/SF_GPH_women_`num', clear
		keep time survivor
		rename survivor S_f
		save `f', replace
	restore
	preserve
		// sts list, saving(${logdir}/SF_GPH_men_`num', replace)
		log using ${logdir}/SF_GPH_men_`num', smcl replace
		sts list if man==1 & country==`num', saving(${logdir}/SF_GPH_men_`num', replace)
		log close
		use ${logdir}/SF_GPH_men_`num', clear
		keep time survivor
		rename survivor S_m
		save `m', replace
	restore
	preserve
		use `all', clear
		merge 1:1 time using `f', nogen
		merge 1:1 time using `m', nogen
		
		
		// fill up 100% at the beginning
		sort time S_all
		sum time
		gen duplicate = `r(min)' if time == `r(min)'
		replace duplicate = 1 if duplicate >=.
		expand duplicate, gen(copy)
		gsort -copy time
		replace time = _n if copy==1
		replace S_all = 1 if copy==1
		replace S_f  = 1 if copy==1
		replace S_m = 1 if copy==1
		drop copy duplicate
		// fill time gaps in survivor functions
		foreach var of varlist S_m S_f S_m {
			capt drop help help2
			gsort -time
			gen help = (`var'<.)
			gen help2 = sum(help)
			gsort +time
			replace `var' = `var'[_n-1] if `var'==. & help2 > 0
		}
		twoway (line S_f time if inrange(time,40,75), sort connect(l) lwidth(vthin) lwidth(thin) lcolor(cranberry*.5) lpattern(solid)) ///
			   (line S_m time if inrange(time,40,75), sort connect(l) lwidth(vthin) lwidth(thin) lcolor(blue*.6) lpattern(solid)) ///
			   (line S_all time if inrange(time,40,75), sort connect(l) lcolor(gs10) lwidth(medium) lpattern(solid)), ///
			   ylabel(0(.25)1,angle(360) labsize(vsmall) format(%9.2g) glwidth(vthin)) ///
			   text( .9 55 "`datasource'", size(*.6) placement(3) justification(left)) text( .8 55 "N=`Nunits', e=`Nevents'", placement(3) size(*.6) justification(left)) ///
			   xlabel(40(5)75, labsize(vsmall)) xscale(range(40 75)) ///
			   xmtick(40(5)75) ///
			   name(scc`num', replace) title("`c'", size(medsmall)) ///
			   xtitle("") ///
			   ytitle("") ///
			   graphregion(color(white)) ///
			   plotregion(style(outline) lwidth(thin) lcolor(black)) ///
			   legend(lab(1 "Mothers") lab(2 "Fathers") lab(3 "Both") ///
					  order(1 2 3) nobox region(lwidth(none) color(none) lcolor(white) lstyle(none)) ///
					  symxsize(*.3) rows(1) cols(3) size(tiny) bmargin(zero) lwidth(none) lcolor(white)) /// 
			   nodraw ///
			   xline(`p75' `p50' `p25', lpattern(solid) lwidth(vthin) lcolor(gs12)) 
			   
	restore
	
	glo sccomb "${sccomb} scc`num'"
	* glo hzcomb "${hzcomb} hzc`num'"
}

/*------------------------------------------------------------------------------
  Figure A1 (I & II)
------------------------------------------------------------------------------*/

* Note: requires user-written command "grc1leg" (ssc install grc1leg)
* Part I
grc1leg scc23 scc3 scc17  /// 
		scc13 scc28 scc19 ///
		scc31 scc25 scc21 ///
		scc29 scc26 scc8, ///
			       legendfrom(scc3) rows(5)  ycommon  /// // iscale(.8)  altshrink xcommon ycommon xsize(8.3) ysize(11.7) 
				   name(SC1, replace) saving("${logdir}/Figure_A1_PARTI.gph", replace) ///
				   graphregion(color(white) margin(l=30 r=30)) ///
				   imargin(2 2 0 2)  /// 
				   title("")
graph export "${logdir}/Figure_A1_PARTI.pdf", replace name(SC1)
graph export "${logdir}/Figure_A1_PARTI.eps", replace name(SC1)

* Part II
grc1leg scc27 scc1 scc16 ///
		scc11 scc7 scc20 ///
		scc18 scc2 scc12 ///
		scc10 scc9 scc15 scc30 scc4, ///
			       legendfrom(scc1) rows(5)  ycommon  /// // iscale(.8)  altshrink xcommon ycommon xsize(8.3) ysize(11.7) 
				   name(SC2, replace) saving("${logdir}/Figure_A1_PARTII.gph", replace) ///
				   graphregion(color(white) margin(l=35 r=35)) ///
				   imargin(2 2 0 2)  /// 
				   title("")
graph export "${logdir}/Figure_A1_PARTII.pdf", replace name(SC2)
graph export "${logdir}/Figure_A1_PARTII.eps", replace name(SC2)




