/*

Replication files 

Leopold, T., & Skopek, J. (2015). The Demography of Grandparenthood: An International Profile. Social Forces, 94(2), 801–832. https://doi.org/10.1093/sf/sov066

Estimating age at grandparenthood (quartile ages). 

Table 4. Quartile Ages at the Transition to Grandparenthood and Probabilities of Being a Grandparent at Different Ages
Figure 1. Women's and men's median ages at the transition to grandparenthood

*/


clear

use ${prepared}/transitions, clear


/*------------------------------------------------------------------------------
  TABLE 4
------------------------------------------------------------------------------*/

/***********************
 Estimate quartile ages for transition to grandparenthood
***********************/

stset t [iweight=nweight] , f(d)  

capt drop raw* 
gen raw = .
gen rawM = .
gen rawF = .

capt drop md* 
gen md = .
gen mdlb = .
gen mdub = .
gen mdM = .
gen mdMlb = .
gen mdMub = .
gen mdF = .
gen mdFlb = .
gen mdFub = .

gen testLR_MF_chi2 = .
gen testLR_MF_p =. 

gen testWC_MF_chi2 = .
gen testWC_MF_p =. 

gen mdNC = .
gen mdMNC = .
gen mdFNC = .

gen mdNE = .
gen mdMNE = .
gen mdFNE = .


foreach num of numlist 1/31 {
	count if country==`num'
	if `r(N)'==0 continue
	di `num'
	quietly {
	
	* compute raw mean first
	quiet: sum _t if _d==1 & country==`num'
	replace raw = `r(mean)' if country==`num'

	// sts 
	
	quiet: stsum if country==`num'
	replace md = `r(p50)' 		if country==`num'
	replace mdlb = `r(p25)' 	if country==`num'
	replace mdub = `r(p75)' 	if country==`num'
	quiet: stdes if country==`num'
	replace mdNC = `r(N_total)' if country==`num'
	replace mdNE = `r(N_fail)' 	if country==`num'
		
	* compute raw mean for men first
	quiet: sum _t if _d==1 & man==1 & country==`num'
	replace rawM = `r(mean)' if country==`num'
	
	quiet: stsum if country==`num' & man==1	
	replace mdM = `r(p50)' 		if country==`num'
	replace mdMlb = `r(p25)' 	if country==`num'
	replace mdMub = `r(p75)' 	if country==`num'
	
	quiet: stdes if country==`num' & man==1
	replace mdMNC = `r(N_total)' 	if country==`num'
	replace mdMNE = `r(N_fail)' 	if country==`num'
	
	* compute raw mean for women first
	quiet: sum _t if _d==1 & man==0 & country==`num'
	replace rawF = `r(mean)' if country==`num'
	
	quiet: stsum if country==`num' & man==0	
	replace mdF = `r(p50)' 			if country==`num'
	replace mdFlb = `r(p25)' 		if country==`num'
	replace mdFub = `r(p75)' 		if country==`num'
	
	quiet: stdes if country==`num' & man==0
	replace mdFNC = `r(N_total)' 	if country==`num'
	replace mdFNE = `r(N_fail)' 	if country==`num'
	
	* Log-Rank test: equality of survivor functions of men and women
	quiet: sts test man if country==`num', logrank
	replace testLR_MF_chi2 = `r(chi2)' if country==`num'
	replace testLR_MF_p = chi2tail(1,`r(chi2)') if country==`num'
	
	* Wilcoxon test: equality of survivor functions of men and women
	quiet: sts test man if country==`num', wilcox
	replace testWC_MF_chi2 = `r(chi2)' if country==`num'
	replace testWC_MF_p = chi2tail(1,`r(chi2)') if country==`num'
	
	}
}

bys country: keep if _n==1
keep country md* test* raw*

format testLR_*_p testWC_*_p %9.3f
li country md mdF mdM testLR_MF_p testWC_MF_p, noobs clean

// Finally, we employed the Wilcoxon-Test as it performs better (more sensitive for differences at the right end of the survivor function)
gen testWC_MF_stars = ""
foreach var in testWC_MF  { 
	replace `var'_stars = cond(`var'_p<0.001, "***", /// 
							   cond(`var'_p<0.01, "**", ///
									cond(`var'_p<0.05,"*", ///
										 cond(`var'_p<0.1,"+",""))))
}
li country md mdF mdM testWC_MF_p testWC_MF_stars, noobs clean





* Get part 1 for Table 4 (quartile ages for men and women as well as wilcoxon test results)
foreach num of numlist 1/4 7/13 15/21 23 25/31 {
	
	foreach item in M F {
		if "`item'"=="M" {
			local sex "men"
		}
		else {
			local sex "women"
		}
		sum md`item'ub if country==`num'
		if `r(N)' == 0 {
			local md`item'ub = .
		} 
		else {
			local md`item'ub = `r(mean)'
		}
		tempfile c
		preserve 
			use ${logdir}/SF_GPH_`sex'_`num', clear
			gen country = `num'
			keep if time==`md`item'ub'
			rename at_risk begin // Note: in previous Stata versions "at_risk" was name "begin". We correct that here. 
			keep country  begin	 
			rename begin md`item'ub_begin 
			save `c'
		restore
		merge 1:1 country using `c', nogen update
	}
}

* Generating a indicator of less than 31 (weighted) cases in risk set at 75% Quartile
gen FsmallN = mdFub_begin < 31
gen MsmallN = mdMub_begin < 31
* Indicator of less than 11 N => not relaiable estimate
gen FnoN = mdFub_begin < 11
gen MnoN = mdMub_begin < 11

tempfile table4_part1
* save ${prepared}/table4_part1, replace
save `table4_part1'

* Get part 2 for Table 4 (probabilities)
use ${prepared}/transitions, clear

stset t [iweight=nweight] , f(d)  

tempfile clab
label save c using `clab'.do, replace 

tempfile lifetable
local i = 1
sum country	
foreach country of numlist 1/`r(max)' {
	
	count if country == `country'
	if `r(N)' == 0 continue
	
	foreach man in 0 1 {
		tempfile c`country'm`man'
		sts list if man==`man' & country==`country' ,  at(45 50 55 60 65 70 75) saving(`c`country'm`man'')
		preserve
			use `c`country'm`man'', clear
			gen country = `country'
			keep time survivor country
			rename survivor S`man'
			save, replace
		restore
	}
	preserve
		use `c`country'm0', clear
		merge 1:1 time country using `c`country'm1', nogen
		tempfile c`country'
		save `c`country''
	restore
	
	if `i' == 1 {
		preserve 
			use `c`country'', clear
			save `lifetable'
		restore
	} 
	else {
		preserve 
			use `lifetable', clear
			append using `c`country''
			save `lifetable', replace
		restore
	}
	local i = `i' + 1
}

use `lifetable', clear
* labels
do `clab'.do
lab val country c

rename S0 W
rename S1 M
reshape wide W M, i(country) j(time)

* Probability of not being grandparent at different ages 
* for women and men
order country W* M*

* percentages
foreach var of varlist W* M* {
	replace `var' = 100*`var'
}
format W* M* %9.1f

* invert: probability of being grandparent
foreach var of varlist W* M* {
	replace `var' = 100*(1 - `var'/100)
}

* women
sort W45 W50 W55 W60 W65 W70 W75
li country W45-W70, clean noobs

* men
*sort M45 M50 M55 M60 M65 M70 M75
li country W45-W70, clean noobs

* no decimals
format W* M* %9.0f
li country W45-W70 M45-M70, clean noobs

tempfile table4_part2
save `table4_part2'



* Merge table parts
use `table4_part1', clear
merge 1:1 country using `table4_part2', keepusing(W45-W70 M45-M70) assert(matched)

*****************
* Export TABLE 4 to excel
****************
isid mdF mdM country
sort mdF mdM country

* list
li country mdFlb mdF mdFub mdMlb mdM mdMub mdlb md mdub  testWC_MF_p testWC_MF_stars FsmallN MsmallN, noobs clean

* export
export excel country mdFlb mdF mdFub mdMlb mdM mdMub mdlb md mdub  testWC_MF_p testWC_MF_stars W45-W70 M45-M70 ///
					 using ${logdir}/Table_4, firstrow(vari) miss("n.a.") replace locale("en")


// Quartile ages women
tabstat mdFlb mdF mdFub, stats(mean sd) f(%9.1f)
tabstat mdMlb mdM mdMub, stats(mean sd) f(%9.1f)

// ukraine, bulgaria, russia, east germany
li country mdFlb mdF mdFub mdMlb mdM mdMub if inlist(country, 23, 3, 19, 31), noobs

// spain, netherlands, West germany, switzerland
li country mdFlb mdF mdFub mdMlb mdM mdMub if inlist(country, 9,15,30,4), noobs

					 
*****************

/*------------------------------------------------------------------------------
  Figure 1 (based on data from table 4)
------------------------------------------------------------------------------*/
* Figure 1
* Total 
capt drop cntrysorted
capt lab drop cntrysorted

// gsort +md -mdlb +mdub 
isid mdF mdM country

gsort -mdF -mdM +country 
gen cntrysorted = _n if country < .

foreach num of numlist 1/31 {
	/*
	count if country == `num'
	if `r(N)' == 0 continue
	*/
	local value = country[`num']
	local string: label (country) `value'
	lab def cntrysorted `num' "`string'", modify
}
lab val cntrysorted cntrysorted


* Only median's by gender
twoway (scatter cntrysorted mdF, mlabel(mdF) msymbol(D) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(vthin) mlcolor(cranberry) msize(medsmall) mcolor(cranberry*.5)) || ///
	   (scatter cntrysorted mdM, mlabel(mdM) msymbol(D) mlabcolor(black) mlabposition(12) mlabgap(*.5) mlabsize(*.4) mlwidth(vthin) mlcolor(blue)  msize(medsmall) mcolor(blue*.6)),  ///
	 	legend(order(1 2 3) lab(1 "Women") lab(2 "Men") /// 
									  position(6) region(style(none) ) bmargin(zero) rows(1) size(tiny)) ///
		graphregion(color(white) margin(l=20 r=20)) ///
		plotregion(style(outline) lwidth(thin)) ///
		ylabel(1(1)26, valuelabels grid glcolor(gs12) angle(360) glwidth(vthin) labsize(*.5)) /// 
		ytitle("") xtitle("Age", size(*.4)) /// 
		xlabel(46(1)61, labsize(*.4) nogrid ) /// 
		xmtick(46(1)61) /// /// xsize(11.7) ysize(8.3) /// scale(.8) ///
		title("") /// 
		xsize(17) ysize(15) /// note("Note. Median age calculated from Kaplan-Meier estimator for women and men having one or more children of age 16 or older;" "calculations weighted by country specific design weights, except for Latvia; ESS data, * GGS data, ** NSFH data;" "countries sorted descending by median age at grandparenthood of women then men.", size(tiny)) ///
		saving("${logdir}/Figure_1.gph", replace) ///
		name(Figure_1, replace)
graph export "${logdir}/Figure_1.pdf", name(Figure_1) replace
graph export "${logdir}/Figure_1.eps", name(Figure_1) replace

// on windows only
// graph export "${logdir}/Figure_1.emf", name(Figure_1) replace













